@@ -1,28 +1,29 @@
 # -*- coding: utf-8 -*-
 from __future__ import division, print_function
 
-from . import cli
-
-import click
-import clodius.chromosomes as cch
-import clodius.multivec as cmv
-import clodius.array as ct
 import collections as col
-import h5py
+import gzip
+import json
 import math
-import negspy.coordinates as nc
-import numpy as np
 import os
 import os.path as op
 import random
-import scipy.misc as sm
-import slugid
 import sqlite3
 import sys
 import time
-import gzip
-import json
 
+import h5py
+import numpy as np
+
+import click
+import clodius.array as ct
+import clodius.chromosomes as cch
+import clodius.multivec as cmv
+import negspy.coordinates as nc
+import scipy.misc as sm
+import slugid
+
+from . import cli
 from .utils import get_tile_pos_from_lng_lat, transaction
 
 
@@ -180,7 +181,7 @@ def _multivec(
 def _bedpe(
     filepath,
     output_file=None,
-    assembly="hg19",
+    assembly=None,
     importance_column="random",
     has_header=False,
     max_per_tile=100,
@@ -1437,10 +1438,7 @@ def bedgraph(
     "with .multires.bed",
 )
 @click.option(
-    "--assembly",
-    "-a",
-    help="The genome assembly that this file was created against",
-    default="hg19",
+    "--assembly", "-a", help="The genome assembly that this file was created against",
 )
 @click.option(
     "--importance-column",
@@ -1528,7 +1526,6 @@ def bedfile(
     "-a",
     help="The genome assembly that this file was created against",
     type=str,
-    default="hg19",
     show_default=True,
 )
 @click.option(
@@ -1545,7 +1542,6 @@ def bedfile(
 @click.option(
     "--has-header/--no-header",
     help="Does this file have a header that we should ignore",
-    type=bool,
     default=False,
     show_default=True,
 )
